.omapi-screen .omapi-campaign-table{margin-top:6px}.omapi-screen .omapi-campaign-table .omapi-add-new.omapi-button__small{margin:0 0 0 15px;padding:4px 8px;margin-bottom:10px;vertical-align:middle}.omapi-screen .omapi-campaign-table__mods{display:flex;flex-wrap:wrap;justify-content:space-between;align-items:center;padding-bottom:3px}.omapi-screen .omapi-campaign-table__mods.omapi-campaign-table__search-wrap,.omapi-screen .omapi-campaign-table__mods>div{margin-bottom:12px}.omapi-screen .omapi-campaign-table__mods .omapi-campaign-table__search-wrap{display:flex;align-items:center;justify-content:center}.omapi-screen .omapi-campaign-table__mods .omapi-campaign-table__search-wrap .subtitle{padding-left:0}.omapi-screen .omapi-campaign-table__mods .omapi-button.omapi-button__large{font-size:13px;line-height:13px;padding:7px 14px}@media screen and (max-width:782px){.omapi-screen .omapi-campaign-table__mods .omapi-button.omapi-button__large{min-height:40px}}.omapi-screen .omapi-campaign-table__mods-bottom{margin:12px 0 4px;justify-content:space-between}.omapi-screen .omapi-campaign-table__mods-bottom>div:only-child{align-self:flex-end;margin-left:auto}.omapi-screen .omapi-campaign-table select{height:30px;border-color:#c9d0d6;vertical-align:top}.omapi-screen .omapi-campaign-table button{vertical-align:top}.omapi-screen .omapi-campaign-table__status{line-height:150%;color:#23282d}.omapi-screen .omapi-campaign-table__status-current{font-weight:600}.omapi-screen .omapi-campaign-table__status-option{color:#087ce1;cursor:pointer}.omapi-screen .omapi-campaign-table__search .omapi-input[type=search].omapi-input__inline{margin:0 10px;height:30px;flex-grow:1}.omapi-screen .omapi-campaign-table__search .omapi-button{margin-right:0}.omapi-screen .omapi-campaign-table__filters-date{align-items:flex-start}.omapi-screen .omapi-campaign-table__filters-date .omapi-dropdown__select{max-width:167px;margin-right:6px}.omapi-screen .omapi-campaign-table__filters-date .omapi-dropdown__select .omapi-dropdown__container{max-width:187px}.omapi-screen .omapi-campaign-table__filters-columns{align-items:flex-start;margin-left:38px}.omapi-screen .omapi-campaign-table__filters-columns .omapi-dropdown__select{max-width:138px;margin-right:6px}.omapi-screen .omapi-campaign-table__filters-columns .omapi-dropdown__select .omapi-dropdown__container{max-width:158px}.omapi-screen .omapi-campaign-table__pagination{margin-left:10px}.omapi-screen .omapi-campaign-table__pagination .omapi-pagination{margin-top:0}.omapi-screen .omapi-campaign-table .om-circle-loading{width:100%}