.omapi-screen .omapi-campaign-settings p{font-size:14px}.omapi-screen .omapi-campaign-settings p.omapi-field-desc{font-size:13px}.omapi-screen .omapi-campaign-settings__wrapper{align-self:flex-start}@media screen and (max-width:1210px){.omapi-screen .omapi-campaign-settings__wrapper{max-width:59%}}@media screen and (max-width:1075px){.omapi-screen .omapi-campaign-settings__wrapper{max-width:100%;flex-basis:100%}}.omapi-screen .omapi-campaign-settings h1{display:flex;justify-content:space-between;align-items:center}.omapi-screen .omapi-campaign-settings .om-circle-loading{width:100%}.omapi-screen .omapi-campaign-settings .setting-label{font-weight:700;display:block;font-size:14px;line-height:1.4}.omapi-screen .omapi-campaign-settings .setting-label.inline{display:inline}.omapi-screen .omapi-campaign-settings .omapi-codebox{margin:0 0 20px}.omapi-screen .omapi-campaign-settings__minor-publishing .omapi-input.omapi-input__select{max-width:1000px}.omapi-screen .omapi-campaign-settings .advanced-settings-enabled-flag{display:inline-block;visibility:hidden;background:rgba(70,180,80,.1);border-radius:4px;padding:5px 7px;font-style:normal;font-weight:700;font-size:13px;line-height:100%;color:#555d66;margin-left:10px}.omapi-screen .omapi-campaign-settings .advanced-settings-enabled-flag.advanced-settings-enabled{visibility:visible}.omapi-screen .omapi-campaign-settings-sections{align-items:flex-start}.omapi-screen .omapi-campaign-settings-sections.disabled>*{position:relative}.omapi-screen .omapi-campaign-settings-sections.disabled>:after,.omapi-screen .omapi-campaign-settings-sections.disabled>:before{content:"";background:#fff;position:absolute;top:0;right:0;left:0;bottom:0;display:block;z-index:99;opacity:.25}.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__inactive{background-color:#f7f8fb;display:flex;border-radius:3px;padding:20px 40px;justify-content:space-between;align-items:center;margin-bottom:30px}@media screen and (max-width:585px){.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__inactive{flex-direction:column;text-align:center}}.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__inactive .omapi-plugin-settings__content{flex-grow:1}.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__logo{margin:0 20px;flex:0 0 98px}.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__logo img{max-width:100%}.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__text{font-size:14px;line-height:150%;margin-bottom:20px;color:#23282d}.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__select-all{padding:4px 10px;font-size:12px;color:#6c7781}.omapi-screen .omapi-campaign-settings .omapi-plugin-settings__select-all:hover{color:#fff}.omapi-screen .omapi-campaign-settings__right-column{align-self:flex-start;max-width:32%}@media screen and (max-width:1210px){.omapi-screen .omapi-campaign-settings__right-column{max-width:40%;flex-basis:40%}}@media screen and (max-width:1075px){.omapi-screen .omapi-campaign-settings__right-column{max-width:100%;flex-basis:100%}}.omapi-screen .omapi-campaign-settings__publish .omapi-card__border{padding-bottom:4px}.omapi-screen .omapi-campaign-settings__publish .omapi-card-footer{background:#f5f5f5;justify-content:space-between}.omapi-screen .omapi-campaign-settings__publish .omapi-button{margin:0}.omapi-screen .omapi-campaign-settings__publish .omapi-input__select{margin:12px 0 20px}.omapi-screen .omapi-campaign-settings__publish label{display:block}.omapi-screen .omapi-campaign-settings__status .omapi-has-tooltip .popper{max-width:840px;width:auto;white-space:normal}.omapi-screen .omapi-campaign-settings .omapi-rules-list{margin-top:0}.omapi-screen .omapi-campaign-settings .omapi-rules-list__item{font-size:14px;color:#646970;line-height:200%}.omapi-screen .omapi-campaign-settings .omapi-rules-list__type{font-weight:600}.omapi-screen .omapi-campaign-settings .omapi-rules-list__toggle{text-align:center;height:1px;margin-top:30px;background:#f1f1f1}.omapi-screen .omapi-campaign-settings .omapi-rules-list__toggle .omapi-button__small{padding:2px 9px;font-size:12px;position:relative;top:-10px}.omapi-screen .omapi-campaign-settings .omapi-card__child{flex-direction:column;align-items:stretch}.omapi-screen .omapi-campaign-settings .omapi-card__child>.omapi-card .omapi-card-content{border-bottom:1px solid #ddd}.omapi-screen .omapi-campaign-settings .omapi-card__child>.omapi-card:last-child .omapi-card-content{border-bottom:none}