"use strict";(self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]=self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]||[]).push([[371],{22513:function(n,e,t){t.r(e),t.d(e,{default:function(){return l}});var r=function(){var n=this,e=n._self._c;return e("core-page",{attrs:{title:"Connect!"}},[e("core-connect-button")],1)},u=[],o=t(81656),p={},s=(0,o.A)(p,r,u,!1,null,null,null),l=s.exports}}]);
//# sourceMappingURL=connect.1e32bc92.js.map