"use strict";(self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]=self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]||[]).push([[758],{37374:function(t,i,s){s.r(i),s.d(i,{default:function(){return u}});var e=function(){var t=this,i=t._self._c;return i("core-page",[i("common-alerts",{attrs:{alerts:t.alerts}}),t.isLoading?i("core-loading",{staticClass:"integrations-loading"}):t._e(),i("transition",{attrs:{name:"fade",mode:"out-in"}},[t.isLoading?t._e():i("div",{staticClass:"omapi-integrations"},[t.showIntegrations?i("div",{staticClass:"omapi-integrations__section"},[i("h2",[t._v("My Integrations")]),i("div",{staticClass:"omapi-integrations-wrap",attrs:{id:"om-my-integrations"}},t._l(t.integrations,(function(t){return i("integrations-integration",{key:t.slug,attrs:{provider:t}})})),1)]):t._e(),t.showFeatured?i("div",{staticClass:"omapi-integrations__section"},[i("h2",[t._v("Featured Integrations")]),i("div",{staticClass:"omapi-integrations-wrap",attrs:{id:"om-featured-integrations"}},t._l(t.featuredProviders,(function(t){return i("integrations-integration",{key:t.slug,attrs:{provider:t}})})),1)]):t._e(),i("div",{staticClass:"omapi-integrations__section all-integrations"},[i("h2",[t._v("All Integrations")]),i("integrations-filters"),i("div",{staticClass:"omapi-integrations-wrap",attrs:{id:"om-all-integrations"}},t._l(t.providers,(function(t){return i("integrations-integration",{key:t.slug,attrs:{provider:t}})})),1),t.showSearchAlert?i("div",{staticClass:"search-alert"},[i("integrations-partials-custom-integrations")],1):t._e()],1)])]),i("integrations-modal-analytics"),i("integrations-modal-custom"),i("templates-modal-not-connected")],1)},r=[],n=s(92100),a=s(95353);const{mapState:o}=(0,a.$t)("integrations");var g={mixins:[n.X],computed:{...o(["integrations","providers","featuredProviders","filters","search","searchResults"]),showSearchAlert(){return(this.isFiltering||this.isSearching)&&0===this.searchResults.length},isLoading(){return this.$store.getters.isLoading("integrations")},alerts(){return this.$get("$store.state.alerts",[])},showIntegrations(){return 0<this.integrations.length},showFeatured(){return 0<this.featuredProviders.length}},created(){this.$store.dispatch("integrations/fetchIntegrationData").catch((()=>{})),this.$store.getters.isFetched("siteSettings")||this.$store.dispatch("settings/fetchSiteSettings").catch((()=>{}))},beforeDestroy(){this.resetProviders()}},l=g,c=s(81656),d=(0,c.A)(l,e,r,!1,null,null,null),u=d.exports}}]);
//# sourceMappingURL=integrations.c4b4d63b.js.map