"use strict";(self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]=self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]||[]).push([[859],{39365:function(e,t,s){s.r(t),s.d(t,{default:function(){return p}});var r=function(){var e=this,t=e._self._c;return t("core-page",{staticClass:"omapi-omu"},[t("common-alerts",{attrs:{id:"omu-errors",alerts:e.alerts}}),e.connected?e._e():t("common-card",{staticClass:"omapi-omu__upgrade"},[t("h2",[e._v("Register now to unlock access to OptinMonster University!")]),t("p",[t("mark",[e._v(" Get instant access to our library of expert courses, guides, video training and ebooks with ANY OptinMonster subscription. ")]),t("br")]),t("core-wizard-button",{attrs:{color:"green",size:"xlarge"}},[e._v("Start Learning Today For Free")])],1),t("common-card",[t("university-courses"),t("hr"),t("university-guides")],1),t("modals-university-promo")],1)},o=[],n=s(95353),i={computed:{...(0,n.L8)(["connected"]),...(0,n.aH)(["alerts"])},mounted(){this.fetchGuides(),this.fetchCourses()},methods:{...(0,n.i0)("omu",["fetchGuides","fetchCourses"])}},u=i,a=s(81656),c=(0,a.A)(u,r,o,!1,null,null,null),p=c.exports}}]);
//# sourceMappingURL=university.4994188f.js.map