.omapi-app-university .omapi-omu__section-header{display:flex;justify-content:space-between;align-items:center;padding-bottom:30px}.omapi-app-university .omapi-omu__section-header h3{margin:0}.omapi-app-university .omapi-omu__grid{flex-wrap:wrap;align-items:flex-start;box-sizing:border-box;overflow:auto}.omapi-app-university .omapi-omu__grid-item{max-width:calc(25% - 16px);flex-basis:25%;margin-bottom:30px}@media screen and (max-width:1000px){.omapi-app-university .omapi-omu__grid-item{max-width:calc(33.33333% - 16px);flex-basis:33%}}@media screen and (max-width:800px){.omapi-app-university .omapi-omu__grid-item{max-width:calc(50% - 16px);flex-basis:50%}}@media screen and (max-width:580px){.omapi-app-university .omapi-omu__grid-item{max-width:160px}}.omapi-app-university .omapi-omu__grid-item h4{font-size:15px;line-height:130%;margin:7px 0}.omapi-app-university .omapi-omu__grid-item h4 a{color:#23282d}.omapi-app-university .omapi-omu__grid-item .omapi-link-arrow-after{display:block;font-size:14px}.omapi-app-university .omapi-omu__grid-item img{width:100%;max-width:300px;height:auto}.omapi-app-university .omapi-omu hr{border:1px solid #f1f1f1;border-width:1px 0 0 0;margin-bottom:30px}.omapi-app-university .omapi-omu .omapi-guides{margin-bottom:-25px}.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb{display:block;background-size:cover;position:relative;padding-bottom:129.4270833%;height:0;border-radius:3px;overflow:hidden}.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb img{border-radius:3px}.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb.no-thumb{background:url(https://optinmonster.com/wp-content/themes/optinmonster-theme/assets/images/guide-placeholder.png) no-repeat 100% 0;background-size:300px;max-width:300px}.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb .guide-title{transition:opacity .2s;position:absolute;top:50%;left:7%;right:18%;color:#fff;line-height:130%;font-size:17px;font-weight:700}@media screen and (min-width:1680px){.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb .guide-title{top:35%}}@media screen and (max-width:1180px){.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb .guide-title{top:35%;font-size:14px}}@media screen and (max-width:1000px){.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb .guide-title{font-size:15px}}@media screen and (max-width:680px){.omapi-app-university .omapi-omu .omapi-guides__guide .guide-thumb .guide-title{top:35%;font-size:14px}}.omapi-app-university .omapi-omu__upgrade .omapi-card-content{display:flex;flex-direction:column;justify-content:center;align-items:center;text-align:center;padding:60px!important}.omapi-app-university .omapi-omu__upgrade h2{font-size:24px;line-height:140%;margin:0 0 14px}.omapi-app-university .omapi-omu__upgrade p{margin-bottom:26px}.omapi-app-university .omapi-omu__upgrade p strong{color:#23282d}.omapi-app-university .omapi-omu__upgrade p mark{background-color:#fefce1;color:#646970;padding:3px}