.omapi-screen .omapi-personalization__filters{display:flex;justify-content:space-between;align-items:center;border-bottom:2px solid #e8e8eb;margin:8px 0 35px}@media screen and (max-width:1139px){.omapi-screen .omapi-personalization__filters{flex-direction:column-reverse}.omapi-screen .omapi-personalization__nav{align-self:flex-start}}.omapi-screen .omapi-personalization__filter{padding:21px 18px 23px;font-size:15px;line-height:1.3em;color:#6c7781;border-bottom:2px solid #e8e8eb;margin-bottom:-2px;cursor:pointer}.omapi-screen .omapi-personalization__filter-active{font-weight:600;color:#23282d;border-bottom-color:#087ce1}@media screen and (max-width:999px){.omapi-screen .omapi-personalization__filter{padding:17px 13px 19px}}.omapi-screen .omapi-personalization__search.campaign-type-filter__search svg{top:9px}@media screen and (max-width:1139px){.omapi-screen .omapi-personalization__search{align-self:flex-end}}.omapi-screen .omapi-personalization__category{border-bottom:1px solid #f1f1f1;margin-bottom:30px;padding-bottom:30px}.omapi-screen .omapi-personalization__category-title{font-size:16px;line-height:1.4em;margin:0 0 30px;display:flex;align-items:center}.omapi-screen .omapi-personalization__category-title>svg{margin-right:5px;height:20px}@media screen and (max-width:1139px){.omapi-screen .omapi-personalization__category__search{align-self:flex-end}}.omapi-screen .omapi-personalization__category:last-child{border-bottom:none;margin-bottom:7px;padding-bottom:0}.omapi-screen .omapi-personalization__rules{display:flex;flex-wrap:wrap}.omapi-screen .omapi-personalization__rule{flex-basis:30.5%;margin-bottom:20px;padding-right:21px;position:relative}.omapi-screen .omapi-personalization__rule-name{margin:0 0 2px;line-height:1.3em;font-size:14px;display:inline-flex;align-items:center}.omapi-screen .omapi-personalization__rule-name svg{height:14px;color:#b5bfc9;margin-left:5px}.omapi-screen .omapi-personalization__rule-name:hover{cursor:pointer}.omapi-screen .omapi-personalization__rule-name:hover .omapi-personalization__rule-create{visibility:visible;transition-delay:0s}.omapi-screen .omapi-personalization__rule-name:hover .omapi-personalization__rule-name svg{color:#087ce1}.omapi-screen .omapi-personalization__rule-desc{color:#646970;line-height:1.4em;font-size:14px}.omapi-screen .omapi-personalization__rule-create{visibility:hidden;position:absolute;width:128px;text-align:center;padding:20px 20px 15px;z-index:111;top:25px;left:-7px;box-shadow:0 3px 15px rgba(0,0,0,.1);border:1px solid #c9d0d6;border-radius:3px;transition-duration:0s;transition-property:visibility;transition-delay:.2s}.omapi-screen .omapi-personalization__rule-create:before{content:"";background:#fff;border-radius:3px;height:100%;width:100%;position:absolute;top:0;left:0}.omapi-screen .omapi-personalization__rule-create:after{content:"";width:10px;background:#fff;top:-5px;left:13px;height:10px;position:absolute;transform:rotate(45deg);z-index:-1;border:1px solid #c9d0d6;border-radius:2px}.omapi-screen .omapi-personalization__rule-create .omapi-button.omapi-button__small{margin:0 0 10px;padding:4px 6px 5px;width:114px;position:relative}.omapi-screen .omapi-personalization__rule-create .omapi-link-arrow-after{margin-right:0;padding-right:0;font-weight:400;font-size:12px;line-height:1;text-decoration-line:underline}.omapi-screen .omapi-personalization__rule-create .omapi-link-arrow-after:after{content:" →";margin-left:0}.omapi-screen .omapi-personalization__rule-add{position:relative;display:inherit}@media screen and (max-width:1199px){.omapi-screen .omapi-personalization__rule{flex-basis:47%}}@media screen and (max-width:999px){.omapi-screen .omapi-personalization__rule{flex-basis:100%;padding-right:0}}