"use strict";(self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]=self["webpackChunkoptinmonster_wordpress_plugin_vue_app"]||[]).push([[952],{29830:function(t,e,s){s.r(e),s.d(e,{default:function(){return g}});var a=function(){var t=this,e=t._self._c;return e("core-page",{staticClass:"omapi-monsterleads-wrapper"},[t.connected||t.isLoading?e("div",[e("common-alerts",{attrs:{alerts:t.alerts}}),e("common-tabnav",{attrs:{active:t.currentTab,tabs:t.allTabs},on:{go:t.navTo}}),e(`monsterleads-${t.currentTab}`,{tag:"component"})],1):e("monsterleads-not-connected"),e("monsterleads-modal-export")],1)},o=[],r=s(95353),n=s(45047),l={mixins:[n.v],data(){return{pageSlug:"monsterleads"}},computed:{...(0,r.aH)(["alerts"]),...(0,r.L8)(["connected","shouldFetchUser"]),isLoading(){return this.shouldFetchUser||this.$store.getters.isLoading("monsterleads")}}},i=l,u=s(81656),c=(0,u.A)(i,a,o,!1,null,null,null),g=c.exports},45047:function(t,e,s){s.d(e,{v:function(){return n}});var a=s(58156),o=s.n(a),r=s(95353);const n={computed:{...(0,r.L8)("tabs",["settingsTab","settingsTabs"]),allTabs(){return this.$store.getters[`tabs/${this.pageSlug}Tabs`]},currentTab(){return this.$store.getters[`tabs/${this.pageSlug}Tab`]},selectedTab(){return this.$get("$route.params.selectedTab")}},mounted(){this.goToSelected()},watch:{$route(t){this.goTo(o()(t,"params.selectedTab"))}},methods:{...(0,r.i0)("tabs",["goTab"]),navTo(t){this.goTab({page:this.pageSlug,tab:t,baseUrl:""})},goTo(t){this.goTab({page:this.pageSlug,tab:t})},goToSelected(){this.selectedTab&&this.goTo(this.selectedTab)}}}}}]);
//# sourceMappingURL=monsterleads.e931d44a.js.map